@@ -20,10 +20,7 @@ TEST_CASE("Instance with surface", "[VkBootstrap.bootstrap]") {
         REQUIRE(sys_info_ret);
 
         vkb::InstanceBuilder instance_builder;
-        auto instance_ret = instance_builder.require_api_version(1, 1, 0)
-                                .set_minimum_instance_version(1, 0, 0)
-                                .use_default_debug_messenger()
-                                .build();
+        auto instance_ret = instance_builder.require_api_version(1, 1, 0).use_default_debug_messenger().build();
         REQUIRE(instance_ret);
         vkb::Instance instance = instance_ret.value();
 
@@ -48,7 +45,6 @@ TEST_CASE("Instance with surface", "[VkBootstrap.bootstrap]") {
         THEN("Can select physical device with customized requirements") {
             vkb::PhysicalDeviceSelector selector(instance);
             auto phys_dev_ret = selector.set_surface(surface)
-                                    .add_desired_extension(VK_KHR_MULTIVIEW_EXTENSION_NAME)
                                     .add_required_extension(VK_KHR_DRIVER_PROPERTIES_EXTENSION_NAME)
                                     .set_minimum_version(1, 0)
                                     .select();
@@ -456,6 +452,25 @@ TEST_CASE("SystemInfo Loading Vulkan Automatically", "[VkBootstrap.loading]") {
     REQUIRE(ret);
 }
 
+TEST_CASE("SystemInfo Check Instance API Version", "[VkBootstrap.instance_api_version]") {
+    VulkanMock& mock = get_and_setup_default();
+    mock.api_version = VK_API_VERSION_1_2;
+    auto info_ret = vkb::SystemInfo::get_system_info();
+    REQUIRE(info_ret);
+    auto system_info = info_ret.value();
+    REQUIRE(system_info.is_instance_version_available(VK_MAKE_API_VERSION(0, 1, 0, 0)));
+    REQUIRE(system_info.is_instance_version_available(VK_MAKE_API_VERSION(0, 1, 1, 0)));
+    REQUIRE(system_info.is_instance_version_available(VK_MAKE_API_VERSION(0, 1, 2, 0)));
+    REQUIRE(!system_info.is_instance_version_available(VK_MAKE_API_VERSION(0, 1, 3, 0)));
+    REQUIRE(!system_info.is_instance_version_available(VK_MAKE_API_VERSION(0, 1, 4, 0)));
+
+    REQUIRE(system_info.is_instance_version_available(1, 0));
+    REQUIRE(system_info.is_instance_version_available(1, 1));
+    REQUIRE(system_info.is_instance_version_available(1, 2));
+    REQUIRE(!system_info.is_instance_version_available(1, 3));
+    REQUIRE(!system_info.is_instance_version_available(1, 4));
+}
+
 TEST_CASE("SystemInfo Loading Vulkan Manually", "[VkBootstrap.loading]") {
     [[maybe_unused]] VulkanMock& mock = get_and_setup_default();
     VulkanLibrary vk_lib;
@@ -517,6 +532,44 @@ TEST_CASE("ReLoading Vulkan Manually", "[VkBootstrap.loading]") {
     }
 }
 
+TEST_CASE("Minimum instance API version", "[VkBootstrap.api_version]") {
+    VulkanMock& mock = get_and_setup_default();
+    mock.api_version = VK_API_VERSION_1_2;
+    mock.physical_devices_details[0].properties.apiVersion = VK_API_VERSION_1_3;
+    mock.physical_devices_details[0].properties.deviceID = 1;
+    add_basic_physical_device(mock).properties.apiVersion = VK_API_VERSION_1_4;
+    mock.physical_devices_details[1].properties.deviceID = 2;
+    {
+        auto ret = vkb::InstanceBuilder{}.set_headless().require_api_version(1, 4).set_minimum_instance_version(1, 2).build();
+        REQUIRE(ret);
+        auto pd_ret = vkb::PhysicalDeviceSelector{ ret.value() }.select();
+        REQUIRE(pd_ret);
+        REQUIRE(pd_ret.value().properties.deviceID == 2);
+    }
+    {
+        auto ret = vkb::InstanceBuilder{}
+                       .set_headless()
+                       .require_api_version(VK_MAKE_API_VERSION(0, 1, 4, 0))
+                       .set_minimum_instance_version(VK_MAKE_API_VERSION(0, 1, 2, 0))
+                       .build();
+        REQUIRE(ret);
+        auto pd_ret = vkb::PhysicalDeviceSelector{ ret.value() }.select();
+        REQUIRE(pd_ret);
+        REQUIRE(pd_ret.value().properties.deviceID == 2);
+    }
+}
+TEST_CASE("Minimum instance API version lower than VkPhysicalDevice", "[VkBootstrap.api_version]") {
+    VulkanMock& mock = get_and_setup_default();
+    mock.api_version = VK_API_VERSION_1_2;
+    mock.physical_devices_details[0].properties.apiVersion = VK_API_VERSION_1_3;
+    mock.physical_devices_details[0].properties.deviceID = 1;
+    {
+        auto ret = vkb::InstanceBuilder{}.set_headless().require_api_version(1, 4).set_minimum_instance_version(1, 2).build();
+        REQUIRE(ret);
+        auto pd_ret = vkb::PhysicalDeviceSelector{ ret.value() }.select();
+        REQUIRE(pd_ret.error() == vkb::PhysicalDeviceError::no_suitable_device);
+    }
+}
 TEST_CASE("Querying Required Extension Features but with 1.0", "[VkBootstrap.select_features]") {
     VulkanMock& mock = get_and_setup_default();
     mock.instance_extensions.push_back(get_extension_properties("VK_KHR_get_physical_device_properties2"));
